#ifndef BUDGETDIALOG_H
#define BUDGETDIALOG_H

#include <QDialog>
#include <QLineEdit>
#include <QWidget>
#include <QCheckBox>

class BudgetDialog : public QDialog
{
        Q_OBJECT
 public:
        BudgetDialog(double current,
                     QWidget *parent = 0,
                     Qt::WindowFlags f = 0);

 signals:
        void changeBudget(double budget);

 private slots:
        void changeBudget();

 private:
        QLineEdit *_budget;
};
#endif
